==> fastyle_dart-1.0.3.tar.gz: lib/ui/themes/dark/dark_colors.dart <==
import 'package:fastyle_dart/ui/ui.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

// Colors
const kFastDarkWhiteColor = Color(0xFFfcfcfc);

const kFastDarkGrayColor = Color(0xFF919191);
const kFastDarkBlueColor = Color(0xFF459ede);
const kFastDarkBlueGrayColor = Color(0xFF699fba);
const kFastDarkTealColor = Color(0xFF76a8ad);
const kFastDarkIndigoColor = Color(0xFF986bb8);
const kFastDarkPurpleColor = Color(0xFFbf5bc8);
const kFastDarkMintColor = Color(0xFF70b2a2);
const kFastDarkGreenColor = Color(0xFF7bb270);
const kFastDarkPinkColor = Color(0xFFf42fb9);
const kFastDarkOrangeColor = Color(0xFFde8f45);
const kFastDarkRedColor = Color(0xFFf4532f);
const kFastDarkYellowColor = Color(0xFFddc23c);
const kFastDarkBrownColor = Color(0xFFad8976);

// Palette Colors

final kFastDarkGrayPaletteColors = FastPaletteScheme.fromColor(
  kFastDarkGrayColor,
);

final kFastDarkBluePaletteColors = FastPaletteScheme.fromColor(
  kFastDarkBlueColor,
);

final kFastDarkBlueGrayPaletteColors = FastPaletteScheme.fromColor(
  kFastDarkBlueGrayColor,
);

final kFastDarkTealPaletteColors = FastPaletteScheme.fromColor(
  kFastDarkTealColor,
);

final kFastDarkIndigoPaletteColors = FastPaletteScheme.fromColor(
  kFastDarkIndigoColor,
);

final kFastDarkPurplePaletteColors = FastPaletteScheme.fromColor(
  kFastDarkPurpleColor,
);

final kFastDarkMintPaletteColors = FastPaletteScheme.fromColor(
  kFastDarkMintColor,
);

final kFastDarkGreenPaletteColors = FastPaletteScheme.fromColor(
  kFastDarkGreenColor,
);

final kFastDarkPinkPaletteColors = FastPaletteScheme.fromColor(
  kFastDarkPinkColor,
);

final kFastDarkRedPaletteColors = FastPaletteScheme.fromColor(
  kFastDarkRedColor,
);

final kFastDarkOrangePaletteColors = FastPaletteScheme.fromColor(
  kFastDarkOrangeColor,
);

final kFastDarkYellowPaletteColors = FastPaletteScheme.fromColor(
  kFastDarkYellowColor,
);

final kFastDarkBrownPaletteColors = FastPaletteScheme.fromColor(
  kFastDarkBrownColor,
);

// Background Colors
final kFastDarkPrimaryBackgroundColor = Color(0xFF0a0b0f);
final kFastDarkSecondaryBackgroundColor = Color(0xFF181b25);
final kFastDarkTertiaryBackgroundColor = Color(0xFF242938);

// Label Colors
final kFastDarkLabelColor = kFastDarkWhiteColor;
final kFastDarkSecondaryLabelColor = kFastDarkGrayPaletteColors.lighter;
final kFastDarkTertiaryLabelColor = kFastDarkGrayPaletteColors.light;
final kFastDarkHintLabelColor = kFastDarkGrayPaletteColors.mid;

// Separator Colors
final kFastDarkSeparatorColor = kFastDarkGrayPaletteColors.darkest;

// Shawdow Colors
const kFastDarkShadowColor = Color(0xFF09090D);

==> fastyle_dart-1.0.4.tar.gz: lib/ui/themes/dark/dark_colors.dart <==
import 'package:fastyle_dart/ui/ui.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

// Colors
const kFastDarkWhiteColor = Color(0xFFfcfcfc);

const kFastDarkGrayColor = Color(0xFF919191);
const kFastDarkBlueColor = Color(0xFF459ede);
const kFastDarkBlueGrayColor = Color(0xFF699fba);
const kFastDarkTealColor = Color(0xFF76a8ad);
const kFastDarkIndigoColor = Color(0xFF986bb8);
const kFastDarkPurpleColor = Color(0xFFbf5bc8);
const kFastDarkMintColor = Color(0xFF70b2a2);
const kFastDarkGreenColor = Color(0xFF7bb270);
const kFastDarkPinkColor = Color(0xFFf42fb9);
const kFastDarkOrangeColor = Color(0xFFde8f45);
const kFastDarkRedColor = Color(0xFFf4532f);
const kFastDarkYellowColor = Color(0xFFddc23c);
const kFastDarkBrownColor = Color(0xFFad8976);

// Palette Colors

final kFastDarkGrayPaletteColors = FastPaletteScheme.fromColor(
  kFastDarkGrayColor,
);

final kFastDarkBluePaletteColors = FastPaletteScheme.fromColor(
  kFastDarkBlueColor,
);

final kFastDarkBlueGrayPaletteColors = FastPaletteScheme.fromColor(
  kFastDarkBlueGrayColor,
);

final kFastDarkTealPaletteColors = FastPaletteScheme.fromColor(
  kFastDarkTealColor,
);

final kFastDarkIndigoPaletteColors = FastPaletteScheme.fromColor(
  kFastDarkIndigoColor,
);

final kFastDarkPurplePaletteColors = FastPaletteScheme.fromColor(
  kFastDarkPurpleColor,
);

final kFastDarkMintPaletteColors = FastPaletteScheme.fromColor(
  kFastDarkMintColor,
);

final kFastDarkGreenPaletteColors = FastPaletteScheme.fromColor(
  kFastDarkGreenColor,
);

final kFastDarkPinkPaletteColors = FastPaletteScheme.fromColor(
  kFastDarkPinkColor,
);

final kFastDarkRedPaletteColors = FastPaletteScheme.fromColor(
  kFastDarkRedColor,
);

final kFastDarkOrangePaletteColors = FastPaletteScheme.fromColor(
  kFastDarkOrangeColor,
);

final kFastDarkYellowPaletteColors = FastPaletteScheme.fromColor(
  kFastDarkYellowColor,
);

final kFastDarkBrownPaletteColors = FastPaletteScheme.fromColor(
  kFastDarkBrownColor,
);

// Background Colors
const kFastDarkPrimaryBackgroundColor = Color(0xFF0a0b0f);
const kFastDarkSecondaryBackgroundColor = Color(0xFF181b25);
const kFastDarkTertiaryBackgroundColor = Color(0xFF242938);

// Label Colors
const kFastDarkLabelColor = kFastDarkWhiteColor;
final kFastDarkSecondaryLabelColor = kFastDarkGrayPaletteColors.lighter;
final kFastDarkTertiaryLabelColor = kFastDarkGrayPaletteColors.light;
final kFastDarkHintLabelColor = kFastDarkGrayPaletteColors.mid;

// Separator Colors
final kFastDarkSeparatorColor = kFastDarkGrayPaletteColors.darkest;

// Shawdow Colors
const kFastDarkShadowColor = Color(0xFF09090D);
